@@ -48,7 +48,7 @@ class DKConnection():
             raise DKOrderRunFailedTestException
         return order_run
 
-    def OrderRunInfo(self, kitchen, order_id):
+    def OrderInfo(self, kitchen, order_id):
         url = "https://%s/v2/order/details/%s" % ( self.hostname, kitchen)
         headers = {'Content-Type': 'application/json', 'Authorization': 'Bearer ' + self.token}
         payload = {'order_id': order_id, 'summary': True, 'logs': True, 'timingresults': True,
@@ -58,11 +58,20 @@ class DKConnection():
             raise Exception("Order run id %s not found." % order_run_id )
         return DKOrder(json.loads(r.text))
 
-    def getOrder(self, kitchen, order_run_id):
-        return self.OrderRunInfo(kitchen, order_run_id)
+    def OrderRunInfo(self, kitchen, order_run_id):
+        url = "https://%s/v2/order/details/%s" % (self.hostname, kitchen)
+        headers = {'Content-Type': 'application/json', 'Authorization': 'Bearer ' + self.token}
+        payload = {'serving_hid': order_run_id, 'testresults': True}
+        r = requests.post(url, headers=headers, data=json.dumps(payload))
+        if "does not exist." in r.text:
+            raise Exception("Order run id %s not found." % order_run_id)
+        return DKOrder(json.loads(r.text))
+
+    def getOrder(self, kitchen, order_id):
+        return self.OrderInfo(kitchen, order_run_id)
 
     def TestsFromOrderRun(self, kitchen, order_run_id):
-        return self.getOrder(kitchen, order_run_id).getTests()
+        return self.getOrderRun(kitchen, order_run_id).getTests()
 
     def OrderStatus(self, kitchen, order_run):
         return self.getOrder(kitchen, order_run_id).getOrderStatus()
