@@ -32,8 +32,6 @@ class DKOrder():
         return False
 
     def getFailedTests(self, test_level):
-        if test_level == "":
-            return list()
         failed_tests = list()
         testResults = self.testsFromOrderRun()
         for level in  ["Failed", "Warning", "Log"]:
@@ -42,6 +40,13 @@ class DKOrder():
                 break
         return failed_tests
 
+    def getFailedTestsByName(self, test_names):
+        for test in self.testResults:
+            if test[2] != "Passed" and test[0] in test_names:
+                return False
+        return True
+
+
     def getOrderStatus(self):
         return self.order_run['orders'][0]['order-status']
 
